@@ -1,16 +1,17 @@
 import configparser
 import logging
 import os
+import re
 import shutil
 import tempfile
 import time
 
 import pytest
+from saltfactories.utils.functional import Loaders
+
 import salt.utils.path
 import salt.utils.pkg
 import salt.utils.platform
-import salt.version
-from saltfactories.utils.functional import Loaders
 
 log = logging.getLogger(__name__)
 
@@ -38,14 +39,8 @@ def preserve_rhel_yum_conf():
     os.remove(tmp_file)
 
 
-@pytest.fixture(autouse=True)
+@pytest.fixture
 def refresh_db(ctx, grains, modules):
-
-    if grains["os"] == "Debian" and grains["osmajorrelease"] == 10:
-        if salt.version.__saltstack_version__.info >= (3006, 0):
-            pytest.fail("Remove this whole Debian 10 check. It's only meant for 3005.x")
-        pytest.skip("Skipped on Debian 10 due to old AMI having issues")
-
     if "refresh" not in ctx:
         modules.pkg.refresh_db()
         ctx["refresh"] = True
@@ -76,10 +71,9 @@ def test_pkg(grains):
     return _pkg
 
 
-@pytest.mark.flaky(max_runs=4)
 @pytest.mark.requires_salt_modules("pkg.list_pkgs")
 @pytest.mark.slow_test
-def test_list(modules):
+def test_list(modules, refresh_db):
     """
     verify that packages are installed
     """
@@ -87,7 +81,6 @@ def test_list(modules):
     assert len(ret.keys()) != 0
 
 
-@pytest.mark.flaky(max_runs=4)
 @pytest.mark.requires_salt_modules("pkg.version_cmp")
 @pytest.mark.slow_test
 def test_version_cmp(grains, modules):
@@ -112,12 +105,11 @@ def test_version_cmp(grains, modules):
     assert modules.pkg.version_cmp(*gt) == 1
 
 
-@pytest.mark.flaky(max_runs=4)
 @pytest.mark.destructive_test
 @pytest.mark.requires_salt_modules("pkg.mod_repo", "pkg.del_repo", "pkg.get_repo")
 @pytest.mark.slow_test
 @pytest.mark.requires_network
-def test_mod_del_repo(grains, modules):
+def test_mod_del_repo(grains, modules, refresh_db):
     """
     test modifying and deleting a software repository
     """
@@ -166,9 +158,8 @@ def test_mod_del_repo(grains, modules):
             modules.pkg.del_repo(repo)
 
 
-@pytest.mark.flaky(max_runs=4)
 @pytest.mark.slow_test
-def test_mod_del_repo_multiline_values(modules):
+def test_mod_del_repo_multiline_values(modules, refresh_db):
     """
     test modifying and deleting a software repository defined with multiline values
     """
@@ -215,23 +206,17 @@ def test_mod_del_repo_multiline_values(modules):
             modules.pkg.del_repo(repo)
 
 
-@pytest.mark.flaky(max_runs=4)
 @pytest.mark.requires_salt_modules("pkg.owner")
-def test_owner(modules, grains):
+def test_owner(modules):
     """
     test finding the package owning a file
     """
-    func = "pkg.owner"
     ret = modules.pkg.owner("/bin/ls")
     assert len(ret) != 0
 
 
-@pytest.mark.flaky(max_runs=4)
 # Similar to pkg.owner, but for FreeBSD's pkgng
-@pytest.mark.skipif(
-    not salt.utils.platform.is_freebsd(),
-    reason="test for new package manager for FreeBSD",
-)
+@pytest.mark.skip_on_freebsd(reason="test for new package manager for FreeBSD")
 @pytest.mark.requires_salt_modules("pkg.which")
 def test_which(modules):
     """
@@ -242,12 +227,11 @@ def test_which(modules):
     assert len(ret) != 0
 
 
-@pytest.mark.flaky(max_runs=4)
 @pytest.mark.destructive_test
 @pytest.mark.requires_salt_modules("pkg.version", "pkg.install", "pkg.remove")
 @pytest.mark.slow_test
 @pytest.mark.requires_network
-def test_install_remove(modules, test_pkg):
+def test_install_remove(modules, test_pkg, refresh_db):
     """
     successfully install and uninstall a package
     """
@@ -272,10 +256,8 @@ def test_install_remove(modules, test_pkg):
         test_remove()
 
 
-@pytest.mark.flaky(max_runs=4)
 @pytest.mark.destructive_test
-@pytest.mark.skipif(
-    salt.utils.platform.is_photonos(),
+@pytest.mark.skip_on_photonos(
     reason="package hold/unhold unsupported on Photon OS",
 )
 @pytest.mark.requires_salt_modules(
@@ -289,7 +271,7 @@ def test_install_remove(modules, test_pkg):
 @pytest.mark.slow_test
 @pytest.mark.requires_network
 @pytest.mark.requires_salt_states("pkg.installed")
-def test_hold_unhold(grains, modules, states, test_pkg):
+def test_hold_unhold(grains, modules, states, test_pkg, refresh_db):
     """
     test holding and unholding a package
     """
@@ -331,12 +313,11 @@ def test_hold_unhold(grains, modules, states, test_pkg):
             assert ret.result is True
 
 
-@pytest.mark.flaky(max_runs=4)
 @pytest.mark.destructive_test
 @pytest.mark.requires_salt_modules("pkg.refresh_db")
 @pytest.mark.slow_test
 @pytest.mark.requires_network
-def test_refresh_db(grains, tmp_path, minion_opts):
+def test_refresh_db(grains, tmp_path, minion_opts, refresh_db):
     """
     test refreshing the package database
     """
@@ -361,10 +342,9 @@ def test_refresh_db(grains, tmp_path, minion_opts):
     assert os.path.isfile(rtag) is False
 
 
-@pytest.mark.flaky(max_runs=4)
 @pytest.mark.requires_salt_modules("pkg.info_installed")
 @pytest.mark.slow_test
-def test_pkg_info(grains, modules, test_pkg):
+def test_pkg_info(grains, modules, test_pkg, refresh_db):
     """
     Test returning useful information on Ubuntu systems.
     """
@@ -389,7 +369,6 @@ def test_pkg_info(grains, modules, test_pkg):
         assert test_pkg in keys
 
 
-@pytest.mark.flaky(max_runs=4)
 @pytest.mark.skipif(True, reason="Temporary Skip - Causes centos 8 test to fail")
 @pytest.mark.destructive_test
 @pytest.mark.requires_salt_modules(
@@ -401,7 +380,7 @@ def test_pkg_info(grains, modules, test_pkg):
 )
 @pytest.mark.slow_test
 @pytest.mark.requires_network
-def test_pkg_upgrade_has_pending_upgrades(grains, modules, test_pkg):
+def test_pkg_upgrade_has_pending_upgrades(grains, modules, test_pkg, refresh_db):
     """
     Test running a system upgrade when there are packages that need upgrading
     """
@@ -471,17 +450,14 @@ def test_pkg_upgrade_has_pending_upgrades(grains, modules, test_pkg):
             assert ret != {}
 
 
-@pytest.mark.flaky(max_runs=4)
 @pytest.mark.destructive_test
-@pytest.mark.skipif(
-    salt.utils.platform.is_darwin() is True,
-    reason="The jenkins user is equivalent to root on mac, causing the test to be"
-    " unrunnable",
+@pytest.mark.skip_on_darwin(
+    reason="The jenkins user is equivalent to root on mac, causing the test to be unrunnable"
 )
 @pytest.mark.requires_salt_modules("pkg.remove", "pkg.latest_version")
 @pytest.mark.slow_test
 @pytest.mark.requires_salt_states("pkg.removed")
-def test_pkg_latest_version(grains, modules, states, test_pkg):
+def test_pkg_latest_version(grains, modules, states, test_pkg, refresh_db):
     """
     Check that pkg.latest_version returns the latest version of the uninstalled package.
     The package is not installed. Only the package version is checked.
@@ -519,7 +495,6 @@ def test_pkg_latest_version(grains, modules, states, test_pkg):
     assert pkg_latest in cmd_pkg
 
 
-@pytest.mark.flaky(max_runs=4)
 @pytest.mark.destructive_test
 @pytest.mark.requires_salt_modules("pkg.list_repos")
 @pytest.mark.slow_test
@@ -561,3 +536,28 @@ def test_list_repos_duplicate_entries(preserve_rhel_yum_conf, grains, modules):
     with pytest.raises(configparser.DuplicateOptionError) as exc_info:
         result = modules.pkg.list_repos()
     assert "{}".format(exc_info.value) == expected
+
+
+@pytest.mark.destructive_test
+@pytest.mark.slow_test
+def test_pkg_install_port(grains, modules):
+    """
+    test install package with a port in the url
+    """
+    pkgs = modules.pkg.list_pkgs()
+    nano = pkgs.get("nano")
+    if nano:
+        modules.pkg.remove("nano")
+
+    if grains["os_family"] == "Debian":
+        url = modules.cmd.run("apt download --print-uris nano").split()[-4]
+        try:
+            ret = modules.pkg.install(sources=f'[{{"nano":{url}}}]')
+            version = re.compile(r"\d\.\d")
+            assert version.search(url).group(0) in ret["nano"]["new"]
+        finally:
+            modules.pkg.remove("nano")
+            if nano:
+                # If nano existed on the machine before the test ran
+                # re-install that version
+                modules.pkg.install(f"nano={nano}")
