@@ -10,6 +10,7 @@ import sys
 from contextlib import closing
 
 import pytest
+
 import salt.utils.files
 
 
@@ -112,6 +113,7 @@ def web_root(tmp_path_factory):
         shutil.rmtree(str(_web_root), ignore_errors=True)
 
 
+@pytest.mark.slow_test
 def test_file_managed_web_source_etag_operation(
     states, free_port, web_root, minion_opts
 ):
@@ -137,7 +139,7 @@ def test_file_managed_web_source_etag_operation(
         minion_opts["cachedir"],
         "extrn_files",
         "base",
-        "localhost:{free_port}".format(free_port=free_port),
+        "localhost{free_port}".format(free_port=free_port),
         "foo.txt",
     )
     cached_etag = cached_file + ".etag"
@@ -199,3 +201,25 @@ def test_file_managed_web_source_etag_operation(
 
     # The modified time of the cached file now changes
     assert cached_file_mtime != os.path.getmtime(cached_file)
+
+
+def test_file_symlink_replace_existing_link(states, tmp_path):
+    # symlink name and target for state
+    name = tmp_path / "foo"
+    target = tmp_path / "baz"
+
+    # create existing symlink to replace
+    old_target = tmp_path / "bar"
+    name.symlink_to(old_target)
+
+    ret = states.file.symlink(
+        name=str(name),
+        target=str(target),
+    )
+
+    assert ret.filtered == {
+        "name": str(name),
+        "changes": {"new": str(name)},
+        "comment": f"Created new symlink {str(name)} -> {str(target)}",
+        "result": True,
+    }
