@@ -6,44 +6,31 @@ from numbers import Number
 from xml.etree import ElementTree
 
 import pytest
-from saltfactories.utils import cli_scripts
-from tests.support.helpers import skip_if_binaries_missing, slowTest
+
+import salt.version
 from tests.support.virt import SaltVirtMinionContainerFactory
 
 docker = pytest.importorskip("docker")
 
-pytestmark = pytest.mark.skipif(
-    True, reason="Skipping tests in 3002.x and 3003.x branches."
-)
-
 log = logging.getLogger(__name__)
 
-
-@pytest.fixture(scope="module")
-def docker_client():
-    urllib3_connectionpool_handler = logging.getLogger("urllib3.connectionpool")
-    urllib3_connectionpool_handler_level = urllib3_connectionpool_handler.level
-    urllib3_connectionpool_handler.setLevel(logging.INFO)
-    try:
-        client = docker.from_env()
-        connectable = SaltVirtMinionContainerFactory.client_connectable(client)
-        if connectable is not True:  # pragma: no cover
-            pytest.skip(connectable)
-        client.images.pull("quay.io/rst0git/virt-minion")
-        yield client
-    finally:
-        urllib3_connectionpool_handler.setLevel(urllib3_connectionpool_handler_level)
+pytestmark = [
+    pytest.mark.slow_test,
+    pytest.mark.skip_if_binaries_missing("docker"),
+]
 
 
-@pytest.fixture(scope="module")
-def salt_minion_script_path(salt_factories):
-    return cli_scripts.generate_script(
-        salt_factories.scripts_dir,
-        "salt-minion",
-        code_dir=salt_factories.code_dir,
-        inject_coverage=salt_factories.inject_coverage,
-        inject_sitecustomize=salt_factories.inject_sitecustomize,
-    )
+def _install_salt_dependencies(container):
+    dependencies = []
+    for package, version in salt.version.dependency_information():
+        if package not in ("packaging", "looseversion"):
+            # These are newer base dependencies which the container might not
+            # yet have
+            continue
+        dependencies.append(f"{package}=={version}")
+    if dependencies:
+        ret = container.run("python3", "-m", "pip", "install", *dependencies)
+        log.debug("Install missing dependecies ret: %s", ret)
 
 
 @pytest.fixture(scope="module")
@@ -58,48 +45,36 @@ def virt_minion_1_id():
 
 @pytest.fixture(scope="module")
 def virt_minion_0(
-    salt_factories,
     salt_master,
-    docker_client,
-    salt_minion_script_path,
     virt_minion_0_id,
     virt_minion_1_id,
 ):
-    root_dir = salt_factories.get_root_dir_for_daemon(virt_minion_0_id)
     config_defaults = {
-        "root_dir": str(root_dir),
         "id": virt_minion_0_id,
         "open_mode": True,
         "transport": salt_master.config["transport"],
     }
     config_overrides = {"user": "root"}
-    config = SaltVirtMinionContainerFactory.configure(
-        factories_manager=salt_factories,
-        daemon_id=virt_minion_0_id,
-        root_dir=root_dir,
-        config_defaults=config_defaults,
-        config_overrides=config_overrides,
-        master=salt_master,
-    )
-    salt_factories.final_minion_config_tweaks(config)
-    loaded_config = SaltVirtMinionContainerFactory.write_config(config)
-    factory = SaltVirtMinionContainerFactory(
+    factory = salt_master.salt_minion_daemon(
+        virt_minion_0_id,
         name=virt_minion_0_id,
-        image="quay.io/rst0git/virt-minion",
-        docker_client=docker_client,
-        config=loaded_config,
-        cli_script_name=salt_minion_script_path,
-        start_timeout=60,
-        factories_manager=salt_factories,
-        event_listener=salt_factories.event_listener,
+        image="ghcr.io/saltstack/salt-ci-containers/virt-minion",
+        factory_class=SaltVirtMinionContainerFactory,
+        defaults=config_defaults,
+        overrides=config_overrides,
         container_run_kwargs={
             "extra_hosts": {
                 virt_minion_0_id: "127.0.0.1",
                 virt_minion_1_id: "127.0.0.1",
-            }
+            },
+            "cgroupns": "host",
         },
+        pull_before_start=True,
+        skip_on_pull_failure=True,
+        skip_if_docker_client_not_connectable=True,
     )
-    factory.register_after_terminate_callback(
+    factory.before_start(_install_salt_dependencies, factory)
+    factory.after_terminate(
         pytest.helpers.remove_stale_minion_key, salt_master, factory.id
     )
     with factory.started():
@@ -108,48 +83,36 @@ def virt_minion_0(
 
 @pytest.fixture(scope="module")
 def virt_minion_1(
-    salt_factories,
     salt_master,
-    docker_client,
-    salt_minion_script_path,
     virt_minion_0_id,
     virt_minion_1_id,
 ):
-    root_dir = salt_factories.get_root_dir_for_daemon(virt_minion_1_id)
     config_defaults = {
-        "root_dir": str(root_dir),
         "id": virt_minion_1_id,
         "open_mode": True,
         "transport": salt_master.config["transport"],
     }
     config_overrides = {"user": "root"}
-    config = SaltVirtMinionContainerFactory.configure(
-        factories_manager=salt_factories,
-        daemon_id=virt_minion_1_id,
-        root_dir=root_dir,
-        config_defaults=config_defaults,
-        config_overrides=config_overrides,
-        master=salt_master,
-    )
-    salt_factories.final_minion_config_tweaks(config)
-    loaded_config = SaltVirtMinionContainerFactory.write_config(config)
-    factory = SaltVirtMinionContainerFactory(
+    factory = salt_master.salt_minion_daemon(
+        virt_minion_1_id,
         name=virt_minion_1_id,
-        image="quay.io/rst0git/virt-minion",
-        docker_client=docker_client,
-        config=loaded_config,
-        cli_script_name=salt_minion_script_path,
-        start_timeout=60,
-        factories_manager=salt_factories,
-        event_listener=salt_factories.event_listener,
+        image="ghcr.io/saltstack/salt-ci-containers/virt-minion",
+        factory_class=SaltVirtMinionContainerFactory,
+        defaults=config_defaults,
+        overrides=config_overrides,
         container_run_kwargs={
             "extra_hosts": {
                 virt_minion_0_id: "127.0.0.1",
                 virt_minion_1_id: "127.0.0.1",
-            }
+            },
+            "cgroupns": "host",
         },
+        pull_before_start=True,
+        skip_on_pull_failure=True,
+        skip_if_docker_client_not_connectable=True,
     )
-    factory.register_after_terminate_callback(
+    factory.before_start(_install_salt_dependencies, factory)
+    factory.after_terminate(
         pytest.helpers.remove_stale_minion_key, salt_master, factory.id
     )
     with factory.started():
@@ -158,11 +121,9 @@ def virt_minion_1(
 
 @pytest.fixture(scope="module")
 def salt_cli(salt_master, virt_minion_0, virt_minion_1):
-    return salt_master.get_salt_cli()
+    return salt_master.salt_cli()
 
 
-@skip_if_binaries_missing("docker")
-@slowTest
 class TestVirtTest:
     """
     Test virt routines
@@ -188,8 +149,8 @@ class TestVirtTest:
         Test virt.get_profiles with the KVM profile
         """
         ret = salt_cli.run("virt.get_profiles", "kvm", minion_tgt=virt_minion_0.id)
-        assert ret.exitcode == 0, ret
-        profiles = ret.json
+        assert ret.returncode == 0, ret
+        profiles = ret.data
         assert isinstance(profiles, dict)
         nic = profiles["nic"]["default"][0]
         disk = profiles["disk"]["default"][0]
@@ -208,8 +169,8 @@ class TestVirtTest:
         Test virt.get_profiles with the VMware profile
         """
         ret = salt_cli.run("virt.get_profiles", "vmware", minion_tgt=virt_minion_0.id)
-        assert ret.exitcode == 0, ret
-        profiles = ret.json
+        assert ret.returncode == 0, ret
+        profiles = ret.data
         assert isinstance(profiles, dict)
         nic = profiles["nic"]["default"][0]
         disk = profiles["disk"]["default"][0]
@@ -229,8 +190,8 @@ class TestVirtTest:
         Test virt.get_profiles with the XEN profile
         """
         ret = salt_cli.run("virt.get_profiles", "xen", minion_tgt=virt_minion_0.id)
-        assert ret.exitcode == 0, ret
-        profiles = ret.json
+        assert ret.returncode == 0, ret
+        profiles = ret.data
         assert isinstance(profiles, dict)
         nic = profiles["nic"]["default"][0]
         disk = profiles["disk"]["default"][0]
@@ -249,8 +210,8 @@ class TestVirtTest:
         Test virt.get_profiles with the Bhyve profile
         """
         ret = salt_cli.run("virt.get_profiles", "bhyve", minion_tgt=virt_minion_0.id)
-        assert ret.exitcode == 0, ret
-        profiles = ret.json
+        assert ret.returncode == 0, ret
+        profiles = ret.data
         assert isinstance(profiles, dict)
         nic = profiles["nic"]["default"][0]
         disk = profiles["disk"]["default"][0]
@@ -271,8 +232,8 @@ class TestVirtTest:
         Test virt.all_capabilities
         """
         ret = salt_cli.run("virt.all_capabilities", minion_tgt=virt_minion_0.id)
-        assert ret.exitcode == 0, ret
-        caps = ret.json
+        assert ret.returncode == 0, ret
+        caps = ret.data
         assert isinstance(caps, dict)
         assert isinstance(caps["host"]["host"]["uuid"], str)
         assert len(caps["host"]["host"]["uuid"]) == 36
@@ -283,8 +244,8 @@ class TestVirtTest:
         Test virt.capabilities
         """
         ret = salt_cli.run("virt.capabilities", minion_tgt=virt_minion_0.id)
-        assert ret.exitcode == 0, ret
-        caps = ret.json
+        assert ret.returncode == 0, ret
+        caps = ret.data
         assert isinstance(caps, dict)
         assert isinstance(caps["host"]["uuid"], str)
         assert len(caps["host"]["uuid"]) == 36
@@ -299,15 +260,15 @@ class TestVirtTest:
         ret = salt_cli.run(
             "virt.cpu_baseline", out="libvirt", minion_tgt=virt_minion_0.id
         )
-        assert ret.exitcode == 0, ret
-        cpu_baseline = ret.json
+        assert ret.returncode == 0, ret
+        cpu_baseline = ret.data
         assert isinstance(cpu_baseline, str)
         cpu_baseline = ElementTree.fromstring(cpu_baseline)
         assert cpu_baseline.find("vendor").text in vendors
 
         ret = salt_cli.run("virt.cpu_baseline", out="salt", minion_tgt=virt_minion_0.id)
-        assert ret.exitcode == 0, ret
-        cpu_baseline = ret.json
+        assert ret.returncode == 0, ret
+        cpu_baseline = ret.data
         assert isinstance(cpu_baseline, dict)
         assert cpu_baseline["vendor"] in vendors
 
@@ -316,8 +277,8 @@ class TestVirtTest:
         Test virt.freemem
         """
         ret = salt_cli.run("virt.freemem", minion_tgt=virt_minion_0.id)
-        assert ret.exitcode == 0, ret
-        available_memory = ret.json
+        assert ret.returncode == 0, ret
+        available_memory = ret.data
         assert isinstance(available_memory, Number)
         assert available_memory > 0
 
@@ -326,8 +287,8 @@ class TestVirtTest:
         Test virt.freecpu
         """
         ret = salt_cli.run("virt.freecpu", minion_tgt=virt_minion_0.id)
-        assert ret.exitcode == 0, ret
-        available_cpus = ret.json
+        assert ret.returncode == 0, ret
+        available_cpus = ret.data
         assert isinstance(available_cpus, Number)
         assert available_cpus > 0
 
@@ -336,8 +297,8 @@ class TestVirtTest:
         Test virt.full_info
         """
         ret = salt_cli.run("virt.full_info", minion_tgt=virt_minion_0.id)
-        assert ret.exitcode == 0, ret
-        info = ret.json
+        assert ret.returncode == 0, ret
+        info = ret.data
         assert isinstance(info, dict)
         assert isinstance(info["vm_info"], dict)
 
@@ -360,8 +321,8 @@ class TestVirtTest:
         Test virt.node_info
         """
         ret = salt_cli.run("virt.node_info", minion_tgt=virt_minion_0.id)
-        assert ret.exitcode == 0, ret
-        info = ret.json
+        assert ret.returncode == 0, ret
+        info = ret.data
         assert isinstance(info, dict)
         assert isinstance(info["cpucores"], Number)
         assert isinstance(info["cpumhz"], Number)
@@ -382,14 +343,14 @@ def virt_domain():
 def prep_virt(salt_cli, virt_minion_0, virt_minion_1, virt_domain):
     try:
         ret = salt_cli.run("virt.list_domains", minion_tgt=virt_minion_0.id)
-        assert ret.exitcode == 0, ret
-        domains = ret.json
+        assert ret.returncode == 0, ret
+        domains = ret.data
         for domain in domains:
             salt_cli.run("virt.stop", virt_domain, minion_tgt=virt_minion_0.id)
             salt_cli.run("virt.undefine", virt_domain, minion_tgt=virt_minion_0.id)
         ret = salt_cli.run("virt.list_domains", minion_tgt=virt_minion_1.id)
-        assert ret.exitcode == 0, ret
-        domains = ret.json
+        assert ret.returncode == 0, ret
+        domains = ret.data
         for domain in domains:
             salt_cli.run("virt.stop", virt_domain, minion_tgt=virt_minion_1.id)
             salt_cli.run("virt.undefine", virt_domain, minion_tgt=virt_minion_1.id)
@@ -398,28 +359,28 @@ def prep_virt(salt_cli, virt_minion_0, virt_minion_1, virt_domain):
             "/{}.xml".format(virt_domain),
             minion_tgt=virt_minion_0.id,
         )
-        assert ret.exitcode == 0, ret
+        assert ret.returncode == 0, ret
         ret = salt_cli.run("virt.start", virt_domain, minion_tgt=virt_minion_0.id)
-        assert ret.exitcode == 0, ret
+        assert ret.returncode == 0, ret
         # Run tests
         yield
     finally:
         ret = salt_cli.run("virt.list_domains", minion_tgt=virt_minion_0.id)
-        assert ret.exitcode == 0, ret
-        domains = ret.json
+        assert ret.returncode == 0, ret
+        domains = ret.data
         for domain in domains:
             salt_cli.run("virt.stop", virt_domain, minion_tgt=virt_minion_0.id)
             salt_cli.run("virt.undefine", virt_domain, minion_tgt=virt_minion_0.id)
         ret = salt_cli.run("virt.list_domains", minion_tgt=virt_minion_1.id)
-        assert ret.exitcode == 0, ret
-        domains = ret.json
+        assert ret.returncode == 0, ret
+        domains = ret.data
         for domain in domains:
             salt_cli.run("virt.stop", virt_domain, minion_tgt=virt_minion_1.id)
             salt_cli.run("virt.undefine", virt_domain, minion_tgt=virt_minion_1.id)
 
 
-@skip_if_binaries_missing("docker")
-@slowTest
+@pytest.mark.slow_test
+@pytest.mark.skip_if_binaries_missing("docker")
 class TestVirtMigrateTest:
     def test_define_xml_path(self, salt_cli, virt_minion_0, virt_domain):
         """
@@ -433,26 +394,26 @@ class TestVirtMigrateTest:
             "/{}.xml".format(virt_domain),
             minion_tgt=virt_minion_0.id,
         )
-        assert ret.exitcode == 0, ret
-        result = ret.json
+        assert ret.returncode == 0, ret
+        result = ret.data
         assert isinstance(result, bool), result
         assert result is True, result
 
         ret = salt_cli.run("virt.list_domains", minion_tgt=virt_minion_0.id)
-        assert ret.exitcode == 0, ret
-        domains = ret.json
+        assert ret.returncode == 0, ret
+        domains = ret.data
         assert isinstance(domains, list)
         assert domains == [virt_domain]
 
         ret = salt_cli.run("virt.undefine", virt_domain, minion_tgt=virt_minion_0.id)
-        assert ret.exitcode == 0, ret
-        result = ret.json
+        assert ret.returncode == 0, ret
+        result = ret.data
         assert isinstance(result, bool)
         assert result is True
 
         ret = salt_cli.run("virt.list_domains", minion_tgt=virt_minion_0.id)
-        assert ret.exitcode == 0, ret
-        domains = ret.json
+        assert ret.returncode == 0, ret
+        domains = ret.data
         assert isinstance(domains, list)
         assert domains == []
 
@@ -463,48 +424,47 @@ class TestVirtMigrateTest:
         Test domain migration over SSH, TCP and TLS transport protocol
         """
         ret = salt_cli.run("virt.list_active_vms", minion_tgt=virt_minion_0.id)
-        assert ret.exitcode == 0, ret
+        assert ret.returncode == 0, ret
 
         ret = salt_cli.run("virt.list_active_vms", minion_tgt=virt_minion_1.id)
-        assert ret.exitcode == 0, ret
+        assert ret.returncode == 0, ret
         ret = salt_cli.run("virt.vm_info", virt_domain, minion_tgt=virt_minion_0.id)
-        assert ret.exitcode == 0, ret
+        assert ret.returncode == 0, ret
 
         # Verify that the VM has been created
         ret = salt_cli.run("virt.list_domains", minion_tgt=virt_minion_0.id)
-        assert ret.exitcode == 0, ret
-        domains = ret.json
+        assert ret.returncode == 0, ret
+        domains = ret.data
         assert isinstance(domains, list)
         assert domains == [virt_domain]
 
         ret = salt_cli.run("virt.list_domains", minion_tgt=virt_minion_1.id)
-        assert ret.exitcode == 0, ret
-        domains = ret.json
+        assert ret.returncode == 0, ret
+        domains = ret.data
         assert isinstance(domains, list)
         assert domains == []
 
         ret = salt_cli.run(
             "virt.migrate",
             virt_domain,
-            virt_minion_1.uri,
-            ssh=True,
+            "qemu+ssh://{}/system".format(virt_minion_1.uri),
             minion_tgt=virt_minion_0.id,
         )
-        assert ret.exitcode == 0, ret
-        result = ret.json
+        assert ret.returncode == 0, ret
+        result = ret.data
         assert isinstance(result, bool)
         assert result is True
 
         # Verify that the VM has been migrated
         ret = salt_cli.run("virt.list_domains", minion_tgt=virt_minion_0.id)
-        assert ret.exitcode == 0, ret
-        domains = ret.json
+        assert ret.returncode == 0, ret
+        domains = ret.data
         assert isinstance(domains, list)
         assert domains == [], "Failed to migrate VM"
 
         ret = salt_cli.run("virt.list_domains", minion_tgt=virt_minion_1.id)
-        assert ret.exitcode == 0, ret
-        domains = ret.json
+        assert ret.returncode == 0, ret
+        domains = ret.data
         assert isinstance(domains, list)
         assert domains == [virt_domain], "Failed to migrate VM"
 
@@ -516,14 +476,14 @@ class TestVirtMigrateTest:
         """
         # Verify that the VM has been created
         ret = salt_cli.run("virt.list_domains", minion_tgt=virt_minion_0.id)
-        assert ret.exitcode == 0, ret
-        domains = ret.json
+        assert ret.returncode == 0, ret
+        domains = ret.data
         assert isinstance(domains, list)
         assert domains == [virt_domain]
 
         ret = salt_cli.run("virt.list_domains", minion_tgt=virt_minion_1.id)
-        assert ret.exitcode == 0, ret
-        domains = ret.json
+        assert ret.returncode == 0, ret
+        domains = ret.data
         assert isinstance(domains, list)
         assert domains == []
 
@@ -533,21 +493,21 @@ class TestVirtMigrateTest:
             virt_minion_1.tcp_uri,
             minion_tgt=virt_minion_0.id,
         )
-        assert ret.exitcode == 0, ret
-        result = ret.json
+        assert ret.returncode == 0, ret
+        result = ret.data
         assert isinstance(result, bool)
         assert result is True
 
         # Verify that the VM has been migrated
         ret = salt_cli.run("virt.list_domains", minion_tgt=virt_minion_0.id)
-        assert ret.exitcode == 0, ret
-        domains = ret.json
+        assert ret.returncode == 0, ret
+        domains = ret.data
         assert isinstance(domains, list)
         assert domains == [], "Failed to migrate VM"
 
         ret = salt_cli.run("virt.list_domains", minion_tgt=virt_minion_1.id)
-        assert ret.exitcode == 0, ret
-        domains = ret.json
+        assert ret.returncode == 0, ret
+        domains = ret.data
         assert isinstance(domains, list)
         assert domains == [virt_domain], "Failed to migrate VM"
 
@@ -559,14 +519,14 @@ class TestVirtMigrateTest:
         """
         # Verify that the VM has been created
         ret = salt_cli.run("virt.list_domains", minion_tgt=virt_minion_0.id)
-        assert ret.exitcode == 0, ret
-        domains = ret.json
+        assert ret.returncode == 0, ret
+        domains = ret.data
         assert isinstance(domains, list)
         assert domains == [virt_domain]
 
         ret = salt_cli.run("virt.list_domains", minion_tgt=virt_minion_1.id)
-        assert ret.exitcode == 0, ret
-        domains = ret.json
+        assert ret.returncode == 0, ret
+        domains = ret.data
         assert isinstance(domains, list)
         assert domains == []
 
@@ -576,20 +536,20 @@ class TestVirtMigrateTest:
             virt_minion_1.tls_uri,
             minion_tgt=virt_minion_0.id,
         )
-        assert ret.exitcode == 0, ret
-        result = ret.json
+        assert ret.returncode == 0, ret
+        result = ret.data
         assert isinstance(result, bool)
         assert result is True
 
         # Verify that the VM has been migrated
         ret = salt_cli.run("virt.list_domains", minion_tgt=virt_minion_0.id)
-        assert ret.exitcode == 0, ret
-        domains = ret.json
+        assert ret.returncode == 0, ret
+        domains = ret.data
         assert isinstance(domains, list)
         assert domains == [], "Failed to migrate VM"
 
         ret = salt_cli.run("virt.list_domains", minion_tgt=virt_minion_1.id)
-        assert ret.exitcode == 0, ret
-        domains = ret.json
+        assert ret.returncode == 0, ret
+        domains = ret.data
         assert isinstance(domains, list)
         assert domains == [virt_domain], "Failed to migrate VM"
