@@ -1,4 +1,5 @@
 import pytest
+
 import salt.client.ssh.client
 import salt.utils.msgpack
 from salt.client import ssh
@@ -6,39 +7,10 @@ from tests.support.mock import MagicMock, patch
 
 pytestmark = [
     pytest.mark.skip_if_binaries_missing("ssh", "ssh-keygen", check_all=True),
+    pytest.mark.slow_test,
 ]
 
 
-@pytest.fixture
-def ssh_target(tmp_path):
-    argv = [
-        "ssh.set_auth_key",
-        "root",
-        "hobn+amNAXSBTiOXEqlBjGB...rsa root@master",
-    ]
-
-    opts = {
-        "argv": argv,
-        "__role": "master",
-        "cachedir": str(tmp_path),
-        "extension_modules": str(tmp_path / "extmods"),
-    }
-    target = {
-        "passwd": "abc123",
-        "ssh_options": None,
-        "sudo": False,
-        "identities_only": False,
-        "host": "login1",
-        "user": "root",
-        "timeout": 65,
-        "remote_port_forwards": None,
-        "sudo_user": "",
-        "port": "22",
-        "priv": "/etc/salt/pki/master/ssh/salt-ssh.rsa",
-    }
-    return opts, target
-
-
 @pytest.fixture
 def opts(tmp_path, temp_salt_master):
     updated_values = {
@@ -58,6 +30,23 @@ def opts(tmp_path, temp_salt_master):
     return opts
 
 
+@pytest.fixture
+def target():
+    return {
+        "passwd": "abc123",
+        "ssh_options": None,
+        "sudo": False,
+        "identities_only": False,
+        "host": "login1",
+        "user": "root",
+        "timeout": 65,
+        "remote_port_forwards": None,
+        "sudo_user": "",
+        "port": "22",
+        "priv": "/etc/salt/pki/master/ssh/salt-ssh.rsa",
+    }
+
+
 @pytest.fixture
 def roster():
     return """
@@ -67,31 +56,6 @@ def roster():
         """
 
 
-@pytest.mark.skip_on_windows(reason="SSH_PY_SHIM not set on windows")
-def test_cmd_block_python_version_error(ssh_target):
-    opts = ssh_target[0]
-    target = ssh_target[1]
-
-    single = ssh.Single(
-        opts,
-        opts["argv"],
-        "localhost",
-        mods={},
-        fsclient=None,
-        thin=salt.utils.thin.thin_path(opts["cachedir"]),
-        mine=False,
-        winrm=False,
-        **target
-    )
-    mock_shim = MagicMock(
-        return_value=(("", "ERROR: Unable to locate appropriate python command\n", 10))
-    )
-    patch_shim = patch("salt.client.ssh.Single.shim_cmd", mock_shim)
-    with patch_shim:
-        ret = single.cmd_block()
-        assert "ERROR: Python version error. Recommendation(s) follow:" in ret[0]
-
-
 @pytest.mark.parametrize(
     "test_opts",
     [
@@ -165,6 +129,51 @@ def test_ssh_kwargs(test_opts):
         assert ssh_obj.opts.get(opt_key, None) == opt_value
 
 
+@pytest.mark.slow_test
+def test_expand_target_ip_address(opts, roster):
+    """
+    test expand_target when target is root@<ip address>
+    """
+    host = "127.0.0.1"
+    user = "test-user@"
+    opts["tgt"] = user + host
+
+    with patch("salt.utils.network.is_reachable_host", MagicMock(return_value=False)):
+        client = ssh.SSH(opts)
+    assert opts["tgt"] == user + host
+    with patch(
+        "salt.roster.get_roster_file", MagicMock(return_value="/etc/salt/roster")
+    ), patch(
+        "salt.client.ssh.compile_template",
+        MagicMock(return_value=salt.utils.yaml.safe_load(roster)),
+    ):
+        client._expand_target()
+    assert opts["tgt"] == host
+
+
+def test_expand_target_no_host(opts, tmp_path):
+    """
+    test expand_target when host is not included in the rosterdata
+    """
+    host = "127.0.0.1"
+    user = "test-user@"
+    opts["tgt"] = user + host
+
+    roster = """
+        localhost: 127.0.0.1
+        """
+    roster_file = str(tmp_path / "test_roster_no_host")
+    with salt.utils.files.fopen(roster_file, "w") as fp:
+        salt.utils.yaml.safe_dump(salt.utils.yaml.safe_load(roster), fp)
+
+    with patch("salt.utils.network.is_reachable_host", MagicMock(return_value=False)):
+        client = ssh.SSH(opts)
+    assert opts["tgt"] == user + host
+    with patch("salt.roster.get_roster_file", MagicMock(return_value=roster_file)):
+        client._expand_target()
+    assert opts["tgt"] == host
+
+
 def test_expand_target_dns(opts, roster):
     """
     test expand_target when target is root@<dns>
